# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.1.1 - 2024-04-21

### Fixed

- Unquote password input before authenticating.

## 0.1.0 - 2024-04-20

### Added

- Add API endpoints for generating OAuth token and uploading recipes.
- Add CLI commands for running app and managing users.
